#!/bin/bash
# create archive from current source using git
set -e

NAME="symas-buildtools"
UPSTREAM_TAG_PREFIX="v"

if test -n "$CI_COMMIT_TAG"; then
    # Undo tag mangling (https://dep-team.pages.debian.net/deps/dep14/) and
    # retrieve upstream version name only
    VERSION="$(echo "${CI_COMMIT_TAG}" | sed -e 'y/%_/:~/' -e 's/#//')"
    VERSION="${VERSION#*/"$NAME"-}"
    VERSION="${VERSION%-*}" # drop revision suffix
    COMMIT="$CI_COMMIT_TAG"
else
    UPSTREAM_VERSION="$(git describe --abbrev=0 --tags --match "${UPSTREAM_TAG_PREFIX}*")"
    LAST_PACKAGE="$(git describe --first-parent --abbrev=0 --tags | sed -e 'y/%_/:~/' -e 's/#//')"
    CURRENT="$(git describe --tags)"

    UPSTREAM_VERSION="${UPSTREAM_VERSION#"${UPSTREAM_TAG_PREFIX}"}"
    LAST_PACKAGE="${LAST_PACKAGE#*/"$NAME"-}"

    if [[ "$CURRENT" =~ / ]]; then
        CURRENT="${CURRENT#*/"$NAME"-}"
        CURRENT="$(echo "$CURRENT" | sed -e 'y/%_/:~/' -e 's/#//')"
    else
        CURRENT="${CURRENT#"${UPSTREAM_TAG_PREFIX}"}"
    fi

    if test "${CURRENT::${#LAST_PACKAGE}}" != "${LAST_PACKAGE}" || \
            test "${CURRENT::${#UPSTREAM_VERSION}}" = "${UPSTREAM_VERSION}"; then
        # Appears to be a new upstream version
        VERSION="$UPSTREAM_VERSION~0"
    elif test "$CURRENT" = "$LAST_PACKAGE"; then
        VERSION="${VERSION%-*}" # drop revision suffix
    else
        # Appears to be new packaging in progress based on last released
        # version - fake upstream changes to trigger our changelog placeholder
        VERSION="$(echo "$CURRENT" | sed -e 's/-[^-]*-\([0-9]*\)-\(g[0-9a-f]*\)$/+\1~\2/')"
    fi

    COMMIT=HEAD
fi

OUTPATH=pkg/archives/dev
NAMEVER="$NAME-v$VERSION"
ARCHIVE="$NAMEVER.tar.xz"
ARPATH="$OUTPATH/$ARCHIVE"

# FIXME for reproducible builds: git archive appears to be deterministic,
# whether its output is stable across versions is another question:
# - If we call git archive with a commit id, it will encode that in the
#   archive, so we wouldn't be able to reproduce the archive across local
#   versions, resolve it to the actual tree-id
mkdir -p "$OUTPATH"
faketime '1970-01-01T00:00:00Z' \
git -c tar.tar.xz.command="xz -c" archive --worktree-attributes --format=tar.xz --output "$ARPATH" --prefix "$NAMEVER/" "$COMMIT^{tree}"

# apkg expects stdout to list archive files
echo "$ARPATH"
